pub fn validate_no_system_properties(
props: &Option<MapLiteral>,
) -> Result<(), ExecutionError>Expand description
Validate that no system properties are being set by the user in a map literal.
pub fn validate_no_system_properties(
props: &Option<MapLiteral>,
) -> Result<(), ExecutionError>Validate that no system properties are being set by the user in a map literal.