Module node_scan

Module node_scan 

Full node scan (with optional label filter).

Functions

execute_node_scan
Scan nodes from the engine, optionally filtered by label. Each node produces a Record with the variable bound to Value::Node(node_id).