Module temporal_scan

Module temporal_scan 

Version-store scan for AT TIME / BETWEEN TIME queries.

Functions

execute_as_of_scan
Execute an AsOfScan: for each node in source records, find the version that was current at the specified timestamp.
execute_temporal_range_scan
Execute a TemporalRangeScan: for each node in source records, find all versions within the specified time range.