Full node scan (with optional label filter).
Functions
- execute_
node_ scan - Scan nodes from the engine, optionally filtered by label. Each node produces a Record with the variable bound to Value::Node(node_id).
Full node scan (with optional label filter).