WITH clause operator.
Functions
- execute_
with - Execute WITH projection: evaluate each ReturnItem and build new records with only the projected columns. This is similar to ProjectOp but serves as an intermediate step rather than final output.